@@ -11,6 +11,8 @@ use bevy::prelude::*;
 /// Implement `Lens` for a custom type:
 ///
 /// ```rust
+/// # use bevy::prelude::*;
+/// # use bevy_tweening::*;
 /// struct MyLens {
 ///   start: f32,
 ///   end: f32,
@@ -88,8 +90,7 @@ pub struct TransformRotationLens {
 
 impl Lens<Transform> for TransformRotationLens {
     fn lerp(&mut self, target: &mut Transform, ratio: f32) {
-        let value = self.start + (self.end - self.start) * ratio;
-        target.rotation = value;
+        target.rotation = self.start.slerp(self.end, ratio); // FIXME - This slerps the shortest path only! https://docs.rs/bevy/latest/bevy/math/struct.Quat.html#method.slerp
     }
 }
 
@@ -139,7 +140,7 @@ impl Lens<Style> for UiPositionLens {
             right: lerp_val(&self.start.right, &self.end.right, ratio),
             top: lerp_val(&self.start.top, &self.end.top, ratio),
             bottom: lerp_val(&self.start.bottom, &self.end.bottom, ratio),
-        }
+        };
     }
 }
 
